#ifndef AGENT_MAGIC_VALUES_H
#define AGENT_MAGIC_VALUES_H

#define AGENT_SCOPE_ALL "max"
#define AGENT_KEY_ISSUERURL "issuer_url"
#define AGENT_KEY_DAESETBYUSER "daeSetByUser"
#define AGENT_KEY_CONFIG_ENDPOINT "config_endpoint"
#define AGENT_KEY_SHORTNAME "name"
#define AGENT_KEY_CERTPATH "cert_path"
#define AGENT_KEY_EXPIRESAT "expires_at"
#define AGENT_KEY_OAUTH "oauth"
#define AGENT_KEY_USESPUBCLIENT "uses_pub_client"
#define AGENT_KEY_MYTOKENURL "mytoken_url"
#define AGENT_KEY_MYTOKENPROFILE "mytoken_profile"

// INTERNAL / CLI FLOW VALUES
#define FLOW_VALUE_CODE "code"
#define FLOW_VALUE_PASSWORD "password"
#define FLOW_VALUE_DEVICE "device"
#define FLOW_VALUE_REFRESH "refresh"
#define FLOW_VALUE_MT_OIDC "mt_oidc"

#define AGENT_CUSTOM_SCHEME "edu.kit.data.oidc-agent:/"

#define FORCE_NEW_TOKEN -1

#endif  // AGENT_MAGIC_VALUES_H
